Welcome to TSPLIB 95's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   pages/readme
   pages/installation
   pages/usage
   pages/modules
   pages/contributing
   pages/authors
   pages/history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
